aboutsummaryrefslogtreecommitdiff
path: root/drivers/media/video/tuner-types.c
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/media/video/tuner-types.c')
-rw-r--r--drivers/media/video/tuner-types.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/drivers/media/video/tuner-types.c b/drivers/media/video/tuner-types.c
index d10cfd400f2..db8b9873029 100644
--- a/drivers/media/video/tuner-types.c
+++ b/drivers/media/video/tuner-types.c
@@ -983,19 +983,19 @@ static struct tuner_params tuner_samsung_tcpn_2121p30a_params[] = {
},
};
-/* ------------ TUNER_FE6600 - DViCO Hybrid PAL ------------ */
+/* ------------ TUNER_THOMSON_FE6600 - DViCO Hybrid PAL ------------ */
-static struct tuner_range tuner_fe6600_ranges[] = {
+static struct tuner_range tuner_thomson_fe6600_ranges[] = {
{ 16 * 160.00 /*MHz*/, 0xfe, 0x11, },
{ 16 * 442.00 /*MHz*/, 0xf6, 0x12, },
{ 16 * 999.99 , 0xf6, 0x18, },
};
-static struct tuner_params tuner_fe6600_params[] = {
+static struct tuner_params tuner_thomson_fe6600_params[] = {
{
.type = TUNER_PARAM_TYPE_PAL,
- .ranges = tuner_fe6600_ranges,
- .count = ARRAY_SIZE(tuner_fe6600_ranges),
+ .ranges = tuner_thomson_fe6600_ranges,
+ .count = ARRAY_SIZE(tuner_thomson_fe6600_ranges),
},
};
@@ -1370,9 +1370,9 @@ struct tunertype tuners[] = {
.name = "Xceive xc3028",
/* see xc3028.c for details */
},
- [TUNER_FE6600] = { /* */
- .name = "FE6600",
- .params = tuner_fe6600_params,
+ [TUNER_THOMSON_FE6600] = { /* Thomson PAL / DVB-T */
+ .name = "Thomson FE6600",
+ .params = tuner_thomson_fe6600_params,
},
};